@@ -342,7 +342,7 @@ class Client:
         self, 
         /, 
         params: str | dict, 
-        payload: str | list | tuple | dict, 
+        data: str | list | tuple | dict, 
     ) -> dict:
         api = "https://pan.baidu.com/api/filemanager"
         if isinstance(params, str):
@@ -356,14 +356,14 @@ class Client:
             "web": 1, 
             **params, 
         }
-        if isinstance(payload, str):
-            payload = {"filelist": dumps([payload])}
-        elif isinstance(payload, dict):
-            if "filelist" not in payload:
-                payload = {"filelist": dumps([payload])}
-        elif isinstance(payload, (list, tuple)):
-            payload = {"filelist": dumps(payload)}
-        return self.request(api, "POST", params=params, data=payload)
+        if isinstance(data, str):
+            data = {"filelist": dumps([data])}
+        elif isinstance(data, dict):
+            if "filelist" not in data:
+                data = {"filelist": dumps([data])}
+        elif isinstance(data, (list, tuple)):
+            data = {"filelist": dumps(data)}
+        return self.request(api, "POST", params=params, data=data)
 
     def copy(
         self, 
@@ -407,7 +407,7 @@ class Client:
         self, 
         /, 
         params: dict, 
-        payload: int | str | list | tuple | dict, 
+        data: int | str | list | tuple | dict, 
     ) -> dict:
         api = "https://pan.baidu.com/share/transfer"
         params = {
@@ -418,11 +418,11 @@ class Client:
             "clienttype": 0, 
             **params, 
         }
-        if isinstance(payload, (int, str)):
-            payload = {"fsidlist": "[%s]" % payload, "path": "/"}
-        elif isinstance(payload, (list, tuple)):
-            payload = {"fsidlist": "[%s]" % ", ".join(map(str, payload)), "path": "/"}
-        return self.request(api, "POST", params=params, payload=payload)
+        if isinstance(data, (int, str)):
+            data = {"fsidlist": "[%s]" % data, "path": "/"}
+        elif isinstance(data, (list, tuple)):
+            data = {"fsidlist": "[%s]" % ", ".join(map(str, data)), "path": "/"}
+        return self.request(api, "POST", params=params, data=data)
 
 
 class ShareList:
